# yamo
Yet Another MongoDB ORM

This is yet another MongoDB ORM for python, features

- Simplicity: more syntax sugars for common operations
- Performance: near zero query/update overhead, do only what must be done

## QuickStart

## Motivation

## Install & Docs


